``desc``: str (Optional)
    The description for the check

``substitute``: bool (Optional)
    | Whether to :ref:`substitute <environment-substitution>` environment variables in
      check values
    | *default*: True
    | *aliases*: ``substitute``, ``env_substitute``
